@@ -21,7 +21,8 @@ fn simple_test() {
     static APP: Component = |cx| {
         cx.render(rsx! {
             Router {
-                onchange: move |route: RouterService| log::info!("route changed to {:?}", route.current_location()),
+                onchange: move |route: RouterService| log::trace!("route changed to {:?}", route.current_location()),
+                active_class: "is-active",
                 Route { to: "/", Home {} }
                 Route { to: "blog"
                     Route { to: "/", BlogList {} }
